tdl.event.MouseButtonEvent

Package tdl :: Module event :: Class MouseButtonEvent |
[frames] | no frames]

# Class MouseButtonEvent

source code

    object --+
             |
         Event --+
                 |
                MouseButtonEvent

Known Subclasses:
  - MouseDown
  - , MouseUp

Instance Methods
__init__(self, button, pos, cell) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__repr__(self) List an events public attributes when printed. (Inherited from tdl.event.Event) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| type = `None` String constant representing the type of event. (Inherited from tdl.event.Event)

Instance Variables
string | button Can be one of 'LEFT', 'MIDDLE', 'RIGHT', 'SCROLLUP', 'SCROLLDOWN'
(int, int) | pos (x, y) position of the mouse on the screen
(int, int) | cell (x, y) position of the mouse snapped to a cell on the root console

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, button, pos, cell) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)